
Qt application
##############

Running the app
===============

A desktop application is installed as part of ``rayoptics``. It is invoked by running ``rayoptics`` at the command line.

.. code::

   > rayoptics

On a Windows machine, the ``rayoptics`` command will be located in a Scripts directory underneath the install directory. For example, if using a virtual environment named ``optics``, the command would be

.. code::

   > \optics\Scripts\rayoptics
